@@ -103,6 +103,9 @@ mailstream_low * mailstream_low_compress_open(mailstream_low * ms)
   if (compress_data == NULL)
     goto err;
 
+  compress_data->compress_stream = NULL;
+  compress_data->decompress_stream = NULL;
+
   /* allocate deflate state */
   compress_data->compress_stream = malloc(sizeof(z_stream));
   compress_data->compress_stream->zalloc = Z_NULL;
@@ -215,9 +218,11 @@ static ssize_t mailstream_low_compress_write(mailstream_low * s, const void * bu
   strm->next_out = data->output_buf;
 
   zr = deflate(strm, Z_PARTIAL_FLUSH);
-  assert(zr == Z_OK);
   if (zr < 0) {
-    printf("Error deflating: %d %s", zr, strm->msg);
+    //STREAM_LOG(s, 1, "<<<<<<< Error deflating ");
+    //STREAM_LOG(s, 1, strm->msg);
+    //STREAM_LOG(s, 1, " <<<<<<<");
+    //STREAM_LOG(s, 1, "\n");
     return -1;
   }
   
