@@ -156,7 +156,7 @@ static void
 
 static int
 	mailimap_condstore_extension_parse(int calling_parser, mailstream * fd,
-	MMAPString * buffer, size_t * indx,
+	MMAPString * buffer, struct mailimap_parser_context * parser_ctx, size_t * indx,
 	struct mailimap_extension_data ** result,
 	size_t progr_rate, progress_function * progr_fun);
 
@@ -331,44 +331,61 @@ struct mailimap_search_key * mailimap_search_key_new_modseq(struct mailimap_flag
 	return key;
 }
 
-int mailimap_search_modseq(mailimap * session, const char * charset,
-	struct mailimap_search_key * key, clist ** result, uint64_t * p_mod_sequence_value)
+static int search_modseq(mailimap * session, const char * charset,
+                         struct mailimap_search_key * key,
+                         int uid_enabled, int literalplus_enabled,
+                         clist ** result, uint64_t * p_mod_sequence_value)
 {
   struct mailimap_response * response;
   int r;
   int error_code;
   struct mailimap_condstore_search * search_data;
   clistiter * cur;
-
+  
   if (session->imap_state != MAILIMAP_STATE_SELECTED)
     return MAILIMAP_ERROR_BAD_STATE;
-
+  
   r = mailimap_send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR)
     return r;
-
-  r = mailimap_search_send(session->imap_stream, charset, key);
+  
+  if (literalplus_enabled) {
+    if (uid_enabled) {
+      r = mailimap_uid_search_literalplus_send(session->imap_stream, charset, key);
+    }
+    else {
+      r = mailimap_search_literalplus_send(session->imap_stream, charset, key);
+    }
+  }
+  else {
+    if (uid_enabled) {
+      r = mailimap_uid_search_send(session->imap_stream, charset, key);
+    }
+    else {
+      r = mailimap_search_send(session->imap_stream, charset, key);
+    }
+  }
   if (r != MAILIMAP_NO_ERROR)
     return r;
-
+  
   r = mailimap_crlf_send(session->imap_stream);
   if (r != MAILIMAP_NO_ERROR)
     return r;
-
+  
   if (mailstream_flush(session->imap_stream) == -1)
     return MAILIMAP_ERROR_STREAM;
-
+  
   if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
-
+  
   r = mailimap_parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR)
     return r;
-
+  
   search_data = NULL;
   for(cur = clist_begin(session->imap_response_info->rsp_extension_list) ; cur != NULL ; cur = clist_next(cur)) {
     struct mailimap_extension_data * ext_data;
-
+    
     ext_data = clist_content(cur);
     if (ext_data->ext_extension->ext_id != MAILIMAP_EXTENSION_CONDSTORE) {
       continue;
@@ -376,12 +393,12 @@ int mailimap_search_modseq(mailimap * session, const char * charset,
     if (ext_data->ext_type != MAILIMAP_CONDSTORE_TYPE_SEARCH_DATA) {
       continue;
     }
-
+    
     search_data = ext_data->ext_data;
     ext_data->ext_data = NULL;
     break;
   }
-
+  
   if (search_data == NULL) {
     * result = session->imap_response_info->rsp_search_result;
     if (p_mod_sequence_value != NULL) {
@@ -395,98 +412,49 @@ int mailimap_search_modseq(mailimap * session, const char * charset,
     search_data->cs_search_result = NULL;
     mailimap_condstore_search_free(search_data);
   }
-
+  
   error_code = response->rsp_resp_done->rsp_data.rsp_tagged->rsp_cond_state->rsp_type;
-
+  
   mailimap_response_free(response);
-
+  
   switch (error_code) {
     case MAILIMAP_RESP_COND_STATE_OK:
-    return MAILIMAP_NO_ERROR;
-
+      return MAILIMAP_NO_ERROR;
+      
     default:
-    return MAILIMAP_ERROR_SEARCH;
+      if (uid_enabled) {
+        return MAILIMAP_ERROR_UID_SEARCH;
+      }
+      else {
+        return MAILIMAP_ERROR_SEARCH;
+      }
   }
 }
 
+int mailimap_search_modseq(mailimap * session, const char * charset,
+	struct mailimap_search_key * key, clist ** result, uint64_t * p_mod_sequence_value)
+{
+  return search_modseq(session, charset, key, 0, 0, result, p_mod_sequence_value);
+}
+
 int mailimap_uid_search_modseq(mailimap * session, const char * charset,
 	struct mailimap_search_key * key, clist ** result, uint64_t * p_mod_sequence_value)
 {
-  struct mailimap_response * response;
-  int r;
-  int error_code;
-  struct mailimap_condstore_search * search_data;
-  clistiter * cur;
+  return search_modseq(session, charset, key, 1, 0, result, p_mod_sequence_value);
+}
 
-  if (session->imap_state != MAILIMAP_STATE_SELECTED)
-    return MAILIMAP_ERROR_BAD_STATE;
+LIBETPAN_EXPORT
+int mailimap_search_literalplus_modseq(mailimap * session, const char * charset,
+                                       struct mailimap_search_key * key, clist ** result, uint64_t * p_mod_sequence_value)
+{
+  return search_modseq(session, charset, key, 0, 1, result, p_mod_sequence_value);
+}
 
-  r = mailimap_send_current_tag(session);
-  if (r != MAILIMAP_NO_ERROR)
-    return r;
-
-  r = mailimap_uid_search_send(session->imap_stream, charset, key);
-  if (r != MAILIMAP_NO_ERROR)
-    return r;
-
-  r = mailimap_crlf_send(session->imap_stream);
-  if (r != MAILIMAP_NO_ERROR)
-    return r;
-
-  if (mailstream_flush(session->imap_stream) == -1)
-    return MAILIMAP_ERROR_STREAM;
-
-  if (mailimap_read_line(session) == NULL)
-    return MAILIMAP_ERROR_STREAM;
-
-  r = mailimap_parse_response(session, &response);
-  if (r != MAILIMAP_NO_ERROR)
-    return r;
-
-  search_data = NULL;
-  for(cur = clist_begin(session->imap_response_info->rsp_extension_list) ; cur != NULL ; cur = clist_next(cur)) {
-    struct mailimap_extension_data * ext_data;
-    
-    ext_data = clist_content(cur);
-    if (ext_data->ext_extension->ext_id != MAILIMAP_EXTENSION_CONDSTORE) {
-      continue;
-    }
-    if (ext_data->ext_type != MAILIMAP_CONDSTORE_TYPE_SEARCH_DATA) {
-      continue;
-    }
-    
-    search_data = ext_data->ext_data;
-    ext_data->ext_data = NULL;
-    break;
-  }
-
-  if (search_data == NULL) {
-    * result = session->imap_response_info->rsp_search_result;
-    if (p_mod_sequence_value != NULL) {
-      * p_mod_sequence_value = 0;
-    }
-    session->imap_response_info->rsp_search_result = NULL;
-  }
-  else {
-    * result = search_data->cs_search_result;
-    if (p_mod_sequence_value != NULL) {
-      * p_mod_sequence_value = search_data->cs_modseq_value;
-    }
-    search_data->cs_search_result = NULL;
-    mailimap_condstore_search_free(search_data);
-  }
-  
-  error_code = response->rsp_resp_done->rsp_data.rsp_tagged->rsp_cond_state->rsp_type;
-
-  mailimap_response_free(response);
-
-  switch (error_code) {
-  case MAILIMAP_RESP_COND_STATE_OK:
-    return MAILIMAP_NO_ERROR;
-
-  default:
-    return MAILIMAP_ERROR_UID_SEARCH;
-  }
+LIBETPAN_EXPORT
+int mailimap_uid_search_literalplus_modseq(mailimap * session, const char * charset,
+                                           struct mailimap_search_key * key, clist ** result, uint64_t * p_mod_sequence_value)
+{
+  return search_modseq(session, charset, key, 1, 1, result, p_mod_sequence_value);
 }
 
 int mailimap_select_condstore(mailimap * session, const char * mb, uint64_t * p_mod_sequence_value)
@@ -667,7 +635,7 @@ int mailimap_has_condstore(mailimap * session)
 }
 
 static int fetch_data_parse(mailstream * fd,
-  MMAPString * buffer, size_t * indx, struct mailimap_condstore_fetch_mod_resp ** result)
+  MMAPString * buffer, struct mailimap_parser_context * parser_ctx, size_t * indx, struct mailimap_condstore_fetch_mod_resp ** result)
 {
   int r;
   size_t cur_token;
@@ -689,15 +657,15 @@ static int fetch_data_parse(mailstream * fd,
   if (r != MAILIMAP_NO_ERROR) {
     return r;
   }
-  r = mailimap_oparenth_parse(fd, buffer, &cur_token);
+  r = mailimap_oparenth_parse(fd, buffer, parser_ctx, &cur_token);
   if (r != MAILIMAP_NO_ERROR) {
     return r;
   }
-  r = mailimap_mod_sequence_value_parse(fd, buffer, &cur_token, &value);
+  r = mailimap_mod_sequence_value_parse(fd, buffer, parser_ctx, &cur_token, &value);
   if (r != MAILIMAP_NO_ERROR) {
     return r;
   }
-  r = mailimap_cparenth_parse(fd, buffer, &cur_token);
+  r = mailimap_cparenth_parse(fd, buffer, parser_ctx, &cur_token);
   if (r != MAILIMAP_NO_ERROR) {
     return r;
   }
@@ -714,7 +682,7 @@ static int fetch_data_parse(mailstream * fd,
 }
 
 static int resp_text_code_parse(mailstream * fd,
-  MMAPString * buffer, size_t * indx, struct mailimap_condstore_resptextcode ** result)
+  MMAPString * buffer, struct mailimap_parser_context * parser_ctx, size_t * indx, struct mailimap_condstore_resptextcode ** result)
 {
   size_t cur_token;
   struct mailimap_condstore_resptextcode * resptextcode;
@@ -727,7 +695,6 @@ static int resp_text_code_parse(mailstream * fd,
     "NOMODSEQ" /
     "MODIFIED" SP set
   */
-  cur_token = * indx;
   
   r = mailimap_token_case_insensitive_parse(fd, buffer, &cur_token, "HIGHESTMODSEQ");
   if (r == MAILIMAP_NO_ERROR) {
@@ -737,7 +704,7 @@ static int resp_text_code_parse(mailstream * fd,
     if (r != MAILIMAP_NO_ERROR) {
       return r;
     }
-    r = mailimap_mod_sequence_value_parse(fd, buffer, &cur_token, &value);
+    r = mailimap_mod_sequence_value_parse(fd, buffer, parser_ctx, &cur_token, &value);
     if (r != MAILIMAP_NO_ERROR) {
       return r;
     }
@@ -771,7 +738,7 @@ static int resp_text_code_parse(mailstream * fd,
       return r;
     }
     
-    r = mailimap_set_parse(fd, buffer, &cur_token, &set);
+    r = mailimap_set_parse(fd, buffer, parser_ctx, &cur_token, &set);
     if (r != MAILIMAP_NO_ERROR) {
       return r;
     }
@@ -791,7 +758,7 @@ static int resp_text_code_parse(mailstream * fd,
 }
 
 static int search_data_parse(mailstream * fd,
-  MMAPString * buffer, size_t * indx, struct mailimap_condstore_search ** result)
+  MMAPString * buffer, struct mailimap_parser_context * parser_ctx, size_t * indx, struct mailimap_condstore_search ** result)
 {
   int r;
   clist * number_list;
@@ -821,7 +788,7 @@ static int search_data_parse(mailstream * fd,
     goto err;
   }
 
-  r = mailimap_struct_spaced_list_parse(fd, buffer, &cur_token, &number_list,
+  r = mailimap_struct_spaced_list_parse(fd, buffer, parser_ctx, &cur_token, &number_list,
     (mailimap_struct_parser *)
     mailimap_nz_number_alloc_parse,
     (mailimap_struct_destructor *)
@@ -837,17 +804,17 @@ static int search_data_parse(mailstream * fd,
     res = r;
     goto free_number_list;
   }
-  r = mailimap_oparenth_parse(fd, buffer, &cur_token);
+  r = mailimap_oparenth_parse(fd, buffer, parser_ctx, &cur_token);
   if (r != MAILIMAP_NO_ERROR) {
     res = r;
     goto free_number_list;
   }
-  r = mailimap_mod_sequence_value_parse(fd, buffer, &cur_token, &value);
+  r = mailimap_mod_sequence_value_parse(fd, buffer, parser_ctx, &cur_token, &value);
   if (r != MAILIMAP_NO_ERROR) {
     res = r;
     goto free_number_list;
   }
-  r = mailimap_cparenth_parse(fd, buffer, &cur_token);
+  r = mailimap_cparenth_parse(fd, buffer, parser_ctx, &cur_token);
   if (r != MAILIMAP_NO_ERROR) {
     res = r;
     goto free_number_list;
@@ -872,7 +839,7 @@ err:
 }
 
 static int status_info_parse(mailstream * fd,
-  MMAPString * buffer, size_t * indx, struct mailimap_condstore_status_info ** result)
+  MMAPString * buffer, struct mailimap_parser_context * parser_ctx, size_t * indx, struct mailimap_condstore_status_info ** result)
 {
   int r;
   struct mailimap_condstore_status_info * status_info;
@@ -882,7 +849,7 @@ static int status_info_parse(mailstream * fd,
   
   cur_token = * indx;
   
-  r = mailimap_status_att_parse(fd, buffer, &cur_token, &status_att);
+  r = mailimap_status_att_parse(fd, buffer, parser_ctx, &cur_token, &status_att);
   if (r != MAILIMAP_NO_ERROR) {
     return r;
   }
@@ -892,7 +859,7 @@ static int status_info_parse(mailstream * fd,
   r = mailimap_space_parse(fd, buffer, &cur_token);
   if (r != MAILIMAP_NO_ERROR)
     return r;
-  r = mailimap_mod_sequence_value_parse(fd, buffer, &cur_token, &value);
+  r = mailimap_mod_sequence_value_parse(fd, buffer, parser_ctx, &cur_token, &value);
   if (r != MAILIMAP_NO_ERROR)
     return r;
     
@@ -908,7 +875,7 @@ static int status_info_parse(mailstream * fd,
 
 static int
 	mailimap_condstore_extension_parse(int calling_parser, mailstream * fd,
-	MMAPString * buffer, size_t * indx,
+	MMAPString * buffer, struct mailimap_parser_context * parser_ctx, size_t * indx,
 	struct mailimap_extension_data ** result,
 	size_t progr_rate, progress_function * progr_fun)
 {
@@ -922,7 +889,7 @@ static int
       struct mailimap_condstore_fetch_mod_resp * fetch_data;
       struct mailimap_extension_data * ext_data;
 
-      r = fetch_data_parse(fd, buffer, &cur_token, &fetch_data);
+      r = fetch_data_parse(fd, buffer, parser_ctx, &cur_token, &fetch_data);
       if (r != MAILIMAP_NO_ERROR)
         return r;
       ext_data = mailimap_extension_data_new(&mailimap_extension_condstore,
@@ -940,7 +907,7 @@ static int
       struct mailimap_condstore_resptextcode * resptextcode;
       struct mailimap_extension_data * ext_data;
       
-      r = resp_text_code_parse(fd, buffer, &cur_token, &resptextcode);
+      r = resp_text_code_parse(fd, buffer, parser_ctx, &cur_token, &resptextcode);
       if (r != MAILIMAP_NO_ERROR)
         return r;
       ext_data = mailimap_extension_data_new(&mailimap_extension_condstore,
@@ -958,7 +925,8 @@ static int
       struct mailimap_condstore_search * search_data;
       struct mailimap_extension_data * ext_data;
       
-      r = search_data_parse(fd, buffer, &cur_token, &search_data);
+      search_data = NULL;
+      r = search_data_parse(fd, buffer, parser_ctx, &cur_token, &search_data);
       if (r != MAILIMAP_NO_ERROR)
         return r;
       ext_data = mailimap_extension_data_new(&mailimap_extension_condstore,
@@ -976,7 +944,7 @@ static int
       struct mailimap_condstore_status_info * status_info;
       struct mailimap_extension_data * ext_data;
       
-      r = status_info_parse(fd, buffer, &cur_token, &status_info);
+      r = status_info_parse(fd, buffer, parser_ctx, &cur_token, &status_info);
       if (r != MAILIMAP_NO_ERROR)
         return r;
       ext_data = mailimap_extension_data_new(&mailimap_extension_condstore,
